Base64Binary

Struct Base64Binary 

pub struct Base64Binary { /* private fields */ }
Base64-encoded byte sequence.

Implementations

Source

impl Base64Binary

pub fn encode(iter: impl IntoIterator<Item = u8>) -> Self

Encode a binary sequence to Base64 binary.

Example
use anyxml_base64::Base64Binary;

let encoded = Base64Binary::encode("Hello".bytes());
assert_eq!(encoded.to_string(), "SGVsbG8=");
pub fn decode(&self) -> impl Iterator<Item = u8> + '_

Decode the Base64 binary back into the original binary sequence.

Example
use anyxml_base64::Base64Binary;

let encoded = Base64Binary::from_encoded(*b"SGVsbG8=", false).unwrap();
let decoded = encoded.decode().map(|b| b as char).collect::<String>();
assert_eq!(decoded, "Hello");
pub fn from_encoded( iter: impl IntoIterator<Item = u8>, allow_whitespace: bool, ) -> Result<Self, Base64Error>

Construct a Base64Binary from a Base64-encoded byte sequence.

When allow_whitespace is true, bytes for which u8::is_ascii_whitespace returns true are ignored during byte sequence validation.

Returns an error if the iter is invalid as a Base64 byte sequence.